@@ -25,7 +25,7 @@ namespace ragel_fix_leaks {
 
         void* reallocate (void* p, size_t oldsz, size_t newsz) {
             auto ret = allocate(newsz);
-            memcpy(ret, p, oldsz);
+            memcpy(ret, p, oldsz > newsz ? newsz : oldsz);
             deallocate(p, oldsz);
             return ret;
         }
